/**
 * @file
 * JavaScript behaviors for the mathfield module.
 */

(function ($) {
  /**
   * The base mathfield namespace.
   */
  var mathfield = Drupal.mathfield = {};

  /**
   * Evaluate the math expression and get the result via ajax.
   */
  mathfield.evaluate = function($element, settings) {
    var evaluate = true;
    var replacements = {};

    if (!$.isEmptyObject(settings.tokens)) {
      // Get token values.
      for (var token in settings.tokens) {
        if (settings.tokens.hasOwnProperty(token)) {
          var handler = settings.tokens[token].handler,
              delta = settings.tokens[token].delta,
              column = settings.tokens[token].column,
              elements = {};

          replacements[token] = mathfield[handler](settings.tokens[token]);
        }
      }

      // Validate replacements.
      for (var token in replacements) {
        if (replacements.hasOwnProperty(token)) {
          if (!$.isNumeric(replacements[token])) {
            // One bad apple spoiles the bunch.
            evaluate = false;
            mathfield.setValue($element, "", settings);
          }
        }
      }
    }

    // Evaluate.
    if (evaluate) {
      $.ajax({
        url: Drupal.settings.basePath + 'js/mathfield/json',
        type: 'POST',
        dataType: 'json',
        cache: true,
        data: {
          callback: 'mathfield_evaluate_expression',
          arguments: {
            expression: settings.expression,
            scale: settings.scale,
            decimal_separator: settings.decimal_separator,
            tokens: replacements
          }
        },
        success: function(data) {
          if (data.success == true) {
            mathfield.setValue($element, data.data, settings);
          }
        },
        error: function(xhr, status, error) {
        }
      });
    }
  }

  /**
   * Get the current value of number field.
   */
  mathfield.getValue = function (settings) {
    return $(settings.selector).val();
  }

  /**
   * Get the current value of a list field.
   */
  mathfield.getListValue = function (settings) {
    var selector = settings.selector;
    if (settings.type == 'radios') {
      selector += ':checked';
    }
    return $(selector).val();
  }

  /**
   * Set the value of a math expression element.
   */
  mathfield.setValue = function ($element, value, settings) {
    $element.val(value).keyup().change();

    // Update the display for read only fields.
    if (settings.widget == 'hidden') {
      $element.next('.form-item').find('.mathfield-display').text(value);
    }
  }

  /**
   * Dynamically perform the selected math expression and display the result.
   */
  Drupal.behaviors.mathfieldMathExpressionForm = {
    attach: function (context, settings) {
      var fields = settings.mathfield;

      for (var i in fields) {
        if (fields.hasOwnProperty(i)) {
          var $mathfield = $('input[name="' + fields[i].name + '"]');
          if (!$.isEmptyObject(fields[i].tokens)) {
            for (var token in fields[i].tokens) {
              if (fields[i].tokens.hasOwnProperty(token)) {
                // Evaluate the expression when the dependent field is changed.
                $(fields[i].tokens[token].selector).bind('change', function (e) {
                  mathfield.evaluate($mathfield, fields[i]);
                }).change();
              }
            }
          }
          else {
            // Evaluate immediately if there are no tokens.
            mathfield.evaluate($mathfield, fields[i]);
          }
        }
      }
    }
  }
})(jQuery);
