<?php

/**
 * @file
 * Hooks provided by Math Field.
 */

/**
 * Get the JavaScript method to determine token values for a field.
 *
 * This hook is invoked on the module that defines the field type. To change
 * the token info for a field define in a different module, use
 * hook_mathfield_get_tokens_alter() or hook_mathfield_get_tokens_MODULE_alter()
 *
 * @param array $context
 *   An associative array with the following keys:
 *   - 'field': The field definition from field_info_field().
 *   - 'instance': The field instance definition from field_info_instance().
 *   - 'delta': The selected delta value for a multivalue field. Default is 0.
 *   - 'column': The selected column for a multicolumn field. Default is 'value'.
 *   - 'form': The complete form definition.
 *   Use list($field, $instance, $delta, $column, $form) = array_values($context)
 *   to populate local variables.
 *
 * @return array
 *   An associative array with the following keys:
 *   - 'handler': The javascript method to get the current value of the field
 *                element. This method must be defined as part of the
 *                Drupal.mathfield namespace.
 *   - 'selector': The jQuery selector for the field element. The 'change' event
 *                 on this element will re-trigger the math evaluation.
 *   - Any other keys required by the 'handler'.
 */
function hook_mathfield_get_tokens($context) {
  list($field, $instance, $delta, $column, $form) = array_values($context);
  $name = $form[$field_name][$language][$delta][$column]['#name'];

  return array(
    'handler' => 'getValue',
    'selector' => "input[name=\"$name\"]",
  );
}

/**
 * Alter the JavaScript method to determine token values for a field.
 *
 * @param array $tokens
 *   The current token value method.
 * @param array $context
 *   An associative array with the following keys:
 *   - 'field': The field definition from field_info_field().
 *   - 'instance': The field instance definition from field_info_instance().
 *   - 'delta': The selected delta value for a multivalue field. Default is 0.
 *   - 'column': The selected column for a multicolumn field. Default is 'value'.
 *   - 'form': The complete form definition.
 *   Use list($field, $instance, $delta, $column, $form) = array_values($context)
 *   to populate local variables.
 *
 *
 */
function hook_mathfield_get_tokens_alter(&$tokens, $context) {
  list($field, $instance, $delta, $column, $form) = array_values($context);
  $field_name = $field['field_name'];
  $language = $form[$field_name]['#language'];
  $name = $form[$field_name][$language][$delta][$column]['#name'];

  $tokens = array(
    'handler' => 'getValue',
    'selector' => "input[name=\"$name\"]",
  );
}

/**
 * Alter the JavaScript method to determine token values for a field.
 *
 * @param array $tokens
 *   The current token value method.
 * @param array $context
 *   An associative array with the following keys:
 *   - 'field': The field definition from field_info_field().
 *   - 'instance': The field instance definition from field_info_instance().
 *   - 'delta': The selected delta value for a multivalue field. Default is 0.
 *   - 'column': The selected column for a multicolumn field. Default is 'value'.
 *   - 'form': The complete form definition.
 *   Use list($field, $instance, $delta, $column, $form) = array_values($context)
 *   to populate local variables.
 */
function hook_mathfield_get_tokens_MODULE_alter(&$tokens, $context) {
  list($field, $instance, $delta, $column, $form) = array_values($context);
  $field_name = $field['field_name'];
  $language = $form[$field_name]['#language'];
  $name = $form[$field_name][$language][$delta][$column]['#name'];

  $tokens = array(
    'handler' => 'getValue',
    'selector' => "input[name=\"$name\"]",
  );
}
